Actions, Resources, and Condition Keys for Amazon GameLift - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon GameLift.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon GameLift

Amazon GameLift (service prefix: `gamelift`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon GameLift
- Resources Defined by Amazon GameLift
- Condition Keys for Amazon GameLift

## Actions Defined by Amazon GameLift

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateAlias | Creates an alias for a fleet | Write |  |  |
CreateBuild | Initializes a new build record and generates information required to upload a game build to Amazon GameLift | Write |  |  |
CreateFleet | Creates a new fleet of computing resources to run your game servers | Write |  |  |
CreateGameSession | Creates a game session for players to join | Write |  |  |
CreatePlayerSession | Adds a player to a game session | Write |  |  |
CreatePlayerSessions | Adds a group of players to a game session | Write |  |  |
DeleteAlias | Deletes an alias | Write |  |  |
DeleteBuild | Deletes a build | Write |  |  |
DeleteFleet | Deletes an empty fleet | Write |  |  |
DeleteScalingPolicy | Deletes a set of scaling rules | Write |  |  |
DescribeAlias | Retrieves properties for an alias | Read |  |  |
DescribeBuild | Retrieves properties for a build | Read |  |  |
DescribeEC2InstanceLimits | Retrieves maximum allowed usage and current usage for all EC2 instance types or a specified type | Read |  |  |
DescribeFleetAttributes | Retrieves general fleet properties for a fleet | Read |  |  |
DescribeFleetCapacity | Retrieves the current capacity status for a fleet | Read |  |  |
DescribeFleetEvents | Retrieves entries from a fleet's event log | Read |  |  |
DescribeFleetPortSettings | Retrieves the inbound connection permissions set for a fleet | Read |  |  |
DescribeFleetUtilization | Retrieves utilization statistics for a fleet | Read |  |  |
DescribeGameSessionDetails | Retrieves game session properties plus game session protection policy | Read |  |  |
DescribeGameSessions | Retrieves game session properties for a fleet | Read |  |  |
DescribeInstances | Retrieves information about a fleet's instances, including instance IDs. | Read |  |  |
DescribePlayerSessions | Retrieves player session properties for a game session | Read |  |  |
DescribeRuntimeConfiguration | Retrieves the runtime configuration for a fleet | Read |  |  |
DescribeScalingPolicies | Retrieves all scaling policies applied to a fleet | Read |  |  |
GetGameSessionLogUrl | Retrieves the location of stored logs for a game session | Read |  |  |
GetInstanceAccess | Requests remote access to a fleet instance. | Read |  |  |
ListAliases | Retrieves the fleet aliases used with this AWS account | List |  |  |
ListBuilds | Retrieves the builds for this AWS account | List |  |  |
ListFleets | Retrieves the fleet for this AWS account | List |  |  |
PutScalingPolicy | Creates or updates a fleet scaling policy | Write |  |  |
RequestUploadCredentials | Retrieves a fresh set of upload credentials and the Amazon S3 storage location for a specific build | Read |  |  |
ResolveAlias | Retrieves the fleet ID associated with an alias | Read |  |  |
SearchGameSessions | Retrieves game sessions that match the search criteria and sorts them as specified | Read |  |  |
UpdateAlias | Updates properties for an alias | Write |  |  |
UpdateBuild | Updates a build's name and version | Write |  |  |
UpdateFleetAttributes | Sets a fleet's general properties | Write |  |  |
UpdateFleetCapacity | Sets a fleet's capacity settings | Write |  |  |
UpdateFleetPortSettings | Sets a fleet's port settings | Write |  |  |
UpdateGameSession | Sets game session properties | Write |  |  |
UpdateRuntimeConfiguration | Sets a fleet's runtime configuration, which specifies how to launch server processes on the fleet | Write |  |  |

## Resources Defined by Amazon GameLift

Amazon GameLift does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon GameLift, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon GameLift

GameLift has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon GameLift
- Resources Defined by Amazon GameLift
- Condition Keys for Amazon GameLift

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more